-- MySQL Script generated by MySQL Workbench
-- 03/17/22 15:41:52
-- Model: New Model    Version: 1.0
-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema sphere
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Schema sphere
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `sphere` DEFAULT CHARACTER SET utf8 ;
USE `sphere` ;

-- -----------------------------------------------------
-- Table `sphere`.`file`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`file` ;

CREATE TABLE IF NOT EXISTS `sphere`.`file` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `filename` VARCHAR(255) NOT NULL,
  `directory` VARCHAR(255) NOT NULL,
  `filetype` ENUM('fits','other') NOT NULL DEFAULT 'fits',
  `size` BIGINT UNSIGNED NULL,
  `date` DATETIME NOT NULL,
  `status` ENUM('exists', 'placeholder', 'error', 'bad', 'to_delete', 'deleted', 'dirty') NOT NULL DEFAULT 'exists',
  `compression` ENUM('none','fz','targz') NOT NULL DEFAULT 'none',
  `is_standard` ENUM('true','false') NOT NULL DEFAULT 'false',
  `storage` ENUM('default','ext') NOT NULL DEFAULT 'default',
  `storage_type` ENUM('sphere', 'cobrex') NOT NULL DEFAULT 'sphere',
  `substorage` SMALLINT NULL,
  `archive_state` ENUM('none','link','copy','archive') NOT NULL DEFAULT 'none',
  `archive_date` TIMESTAMP NULL,
  `last_use_date` TIMESTAMP NULL,
  PRIMARY KEY (`id`),
  INDEX `idx_file_filename` (`filename` ASC),
  INDEX `idx_file_directory` (`directory` ASC),
  UNIQUE INDEX `uq_file_filename_directory` (`filename` ASC, `directory` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`frame_type`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`frame_type` ;

CREATE TABLE IF NOT EXISTS `sphere`.`frame_type` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `type` ENUM('esorex', 'custom', 'executable') NOT NULL DEFAULT 'esorex',
  `data_type` ENUM('science', 'calibration') NULL,
  `description` TEXT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `name_UNIQUE` (`name` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`user`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`user` ;

CREATE TABLE IF NOT EXISTS `sphere`.`user` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `login` VARCHAR(255) NOT NULL,
  `ident` VARCHAR(255) NULL,
  `email` VARCHAR(255) NOT NULL,
  `display` VARCHAR(255) NULL,
  `password` VARCHAR(32) NOT NULL,
  `role` ENUM('user', 'admin', 'manager', 'producer', 'dev', 'guest', 'sandbox', 'data_distribution', 'workflow_producer') NOT NULL DEFAULT 'user',
  `restricted` ENUM('true','false') NOT NULL DEFAULT 'false',
  `deleted` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `creation_date` TIMESTAMP NULL,
  `last_login_date` TIMESTAMP NULL,
  `last_login_ip` VARCHAR(24) NULL,
  `settings` TEXT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `login_UNIQUE` (`login` ASC),
  UNIQUE INDEX `email_UNIQUE` (`email` ASC),
  UNIQUE INDEX `display_UNIQUE` (`display` ASC),
  UNIQUE INDEX `ident_UNIQUE` (`ident` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`raw_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`raw_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`raw_data` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `frame_type_id` INT UNSIGNED NOT NULL,
  `type` ENUM('observation','calibration') NOT NULL DEFAULT 'observation',
  `user_id` INT UNSIGNED NULL,
  `date` DATETIME NOT NULL,
  `obs_date` DATETIME NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_raw_data_frame_type1_idx` (`frame_type_id` ASC),
  INDEX `fk_raw_data_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_raw_data_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_raw_data_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`instrument`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`instrument` ;

CREATE TABLE IF NOT EXISTS `sphere`.`instrument` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `acronym` VARCHAR(10) NOT NULL,
  `mode` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_instrument_name` (`name` ASC),
  UNIQUE INDEX `uq_instrument_acronym` (`acronym` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`person`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`person` ;

CREATE TABLE IF NOT EXISTS `sphere`.`person` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `email` VARCHAR(255) NULL,
  `type` ENUM('recipe_author') NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `person_uq_name_email_type` (`name` ASC, `email` ASC, `type` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`pipeline`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`pipeline` ;

CREATE TABLE IF NOT EXISTS `sphere`.`pipeline` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `version` VARCHAR(255) NOT NULL,
  `build` VARCHAR(100) NULL,
  `type` ENUM('esorex','executable') NOT NULL DEFAULT 'esorex',
  `is_current_version` ENUM('true','false') NOT NULL DEFAULT 'false',
  `directory` VARCHAR(255) NOT NULL,
  `lib_directory` VARCHAR(255) NOT NULL,
  `install_date` DATE NULL,
  `notes` TEXT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uk_pipeline_version` (`version` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`executable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`executable` ;

CREATE TABLE IF NOT EXISTS `sphere`.`executable` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `path` VARCHAR(255) NULL,
  `bin` VARCHAR(255) NOT NULL,
  `script` VARCHAR(255) NULL,
  `use_sof` ENUM('true','false') NOT NULL DEFAULT 'false',
  `parameter_prefix` VARCHAR(10) NULL,
  `user_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_executable_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_executable_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`recipe`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`recipe` ;

CREATE TABLE IF NOT EXISTS `sphere`.`recipe` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `pipeline_id` INT UNSIGNED NOT NULL,
  `instrument_id` INT UNSIGNED NOT NULL,
  `executable_id` INT UNSIGNED NULL,
  `name` VARCHAR(255) NOT NULL,
  `date` DATE NULL,
  `person_id` INT UNSIGNED NULL,
  `is_hidden` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `short_description` VARCHAR(255) NULL,
  `description` TEXT NULL,
  `synopsis` VARCHAR(255) NULL,
  `license` VARCHAR(255) NULL,
  `raw_man_page` TEXT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_recipe_instrument1_idx` (`instrument_id` ASC),
  UNIQUE INDEX `uq_recipe_name_pipeline_id` (`name` ASC, `pipeline_id` ASC),
  INDEX `fk_recipe_person1_idx` (`person_id` ASC),
  INDEX `fk_recipe_pipeline1_idx` (`pipeline_id` ASC),
  INDEX `fk_recipe_executable1_idx` (`executable_id` ASC),
  CONSTRAINT `fk_recipe_instrument1`
    FOREIGN KEY (`instrument_id`)
    REFERENCES `sphere`.`instrument` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_person1`
    FOREIGN KEY (`person_id`)
    REFERENCES `sphere`.`person` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_pipeline1`
    FOREIGN KEY (`pipeline_id`)
    REFERENCES `sphere`.`pipeline` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_executable1`
    FOREIGN KEY (`executable_id`)
    REFERENCES `sphere`.`executable` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workflow`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workflow` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workflow` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `pipeline_id` INT UNSIGNED NOT NULL,
  `type` ENUM('workflow','auto_reduction') NOT NULL DEFAULT 'workflow',
  `multiplepass` VARCHAR(45) NULL,
  `comments` TEXT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_workflow_name_pipeline_id` (`name` ASC, `pipeline_id` ASC),
  INDEX `fk_workflow_pipeline1_idx` (`pipeline_id` ASC),
  CONSTRAINT `fk_workflow_pipeline1`
    FOREIGN KEY (`pipeline_id`)
    REFERENCES `sphere`.`pipeline` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workflowpreset`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workflowpreset` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workflowpreset` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `workflow_id` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_workflowpreset_workflow1_idx` (`workflow_id` ASC),
  UNIQUE INDEX `uq_workflow_id_name` (`workflow_id` ASC, `name` ASC),
  CONSTRAINT `fk_workflowpreset_workflow1`
    FOREIGN KEY (`workflow_id`)
    REFERENCES `sphere`.`workflow` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workspace`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workspace` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workspace` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) NOT NULL,
  `creation_date` TIMESTAMP NOT NULL,
  `auto_import` ENUM('true','false') NOT NULL DEFAULT 'false',
  `is_public` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `comments` TEXT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_workspace_user1_idx` (`user_id` ASC),
  UNIQUE INDEX `uq_workspace_user_id_name` (`user_id` ASC, `name` ASC),
  CONSTRAINT `fk_workspace_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`launcher`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`launcher` ;

CREATE TABLE IF NOT EXISTS `sphere`.`launcher` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `is_grid` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `is_dev` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `is_used` ENUM('true', 'false') NOT NULL DEFAULT 'true',
  `label` VARCHAR(255) GENERATED ALWAYS AS (CONCAT(name, IF(is_dev = 'true', '-dev', ''), IF(is_grid = 'true', '-grid', ''))) VIRTUAL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_launcher_name_grid_dev1` (`name` ASC, `is_grid` ASC, `is_dev` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`batch`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`batch` ;

CREATE TABLE IF NOT EXISTS `sphere`.`batch` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `parent_batch_id` INT UNSIGNED NULL,
  `workflow_id` INT UNSIGNED NOT NULL,
  `workflowpreset_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `workspace_id` INT UNSIGNED NULL,
  `launcher` ENUM('local', 'grid', 'dev_local', 'dev_grid') NULL DEFAULT 'local',
  `launcher_id` INT UNSIGNED NULL,
  `status` ENUM('prepared', 'associating', 'started', 'finished', 'error') NOT NULL,
  `control_status` ENUM('auto', 'pause', 'stop') NULL DEFAULT 'auto',
  `step` TINYINT UNSIGNED NULL,
  `pass` TINYINT NULL,
  `start_time` TIMESTAMP NULL,
  `last_activity` TIMESTAMP NULL,
  `end_time` TIMESTAMP NULL,
  `obs_night` DATE NULL,
  `submitted_date` TEXT NULL,
  `min_step` TINYINT UNSIGNED NULL,
  `max_step` TINYINT UNSIGNED NULL,
  `time_range` INT NULL,
  `force_standard` ENUM('true', 'false') NULL DEFAULT 'false',
  `use_target_as_object` ENUM('true', 'false') NULL DEFAULT 'false',
  `propagate_workspace` ENUM('true', 'false') NULL DEFAULT 'false',
  `own_batch_source` ENUM('true', 'false') NULL DEFAULT 'false',
  `relaunched` ENUM('true', 'false') NULL DEFAULT 'false',
  `log` MEDIUMTEXT NULL,
  `grid_log` MEDIUMTEXT NULL,
  `state` MEDIUMTEXT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_batch_workflow1_idx` (`workflow_id` ASC),
  INDEX `fk_batch_workflowpreset1_idx` (`workflowpreset_id` ASC),
  INDEX `fk_batch_user1_idx` (`user_id` ASC),
  INDEX `fk_batch_workspace1_idx` (`workspace_id` ASC),
  INDEX `fk_batch_batch1_idx` (`parent_batch_id` ASC),
  INDEX `fk_batch_launcher1_idx` (`launcher_id` ASC),
  CONSTRAINT `fk_batch_workflow1`
    FOREIGN KEY (`workflow_id`)
    REFERENCES `sphere`.`workflow` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_batch_workflowpreset1`
    FOREIGN KEY (`workflowpreset_id`)
    REFERENCES `sphere`.`workflowpreset` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_batch_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_batch_workspace1`
    FOREIGN KEY (`workspace_id`)
    REFERENCES `sphere`.`workspace` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_batch_batch1`
    FOREIGN KEY (`parent_batch_id`)
    REFERENCES `sphere`.`batch` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_batch_launcher1`
    FOREIGN KEY (`launcher_id`)
    REFERENCES `sphere`.`launcher` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`preset`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`preset` ;

CREATE TABLE IF NOT EXISTS `sphere`.`preset` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) NOT NULL,
  `is_default` ENUM('true','false') NOT NULL DEFAULT 'false',
  PRIMARY KEY (`id`),
  INDEX `fk_preset_recipe1_idx` (`recipe_id` ASC),
  UNIQUE INDEX `uq_preset_name_recipe_id` (`recipe_id` ASC, `name` ASC),
  CONSTRAINT `fk_preset_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`process`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`process` ;

CREATE TABLE IF NOT EXISTS `sphere`.`process` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `batch_id` INT UNSIGNED NULL,
  `parent_process_id` INT UNSIGNED NULL,
  `top_parent_process_id` INT UNSIGNED NULL,
  `preset_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `data_pipeline_id` INT UNSIGNED NULL,
  `job_id` INT UNSIGNED NULL,
  `uuid` VARCHAR(255) NULL,
  `status` ENUM('preparing', 'prepared', 'submitted', 'waiting_parent', 'waiting_validation', 'started', 'finishing', 'finished', 'failed', 'error') NOT NULL DEFAULT 'prepared',
  `previous_status` ENUM('preparing', 'prepared', 'submitted', 'waiting_parent', 'waiting_validation', 'started', 'finishing', 'finished', 'failed', 'error') NULL,
  `is_standard` ENUM('true','false') NOT NULL DEFAULT 'false',
  `need_validation` ENUM('true','false') NOT NULL DEFAULT 'false',
  `validation_status` ENUM('no_need','to_validate','validated','to_reprocess','reprocessed','rejected','calibration_rejected','temporary') NOT NULL DEFAULT 'no_need',
  `previous_validation_status` ENUM('no_need','to_validate','validated','to_reprocess','reprocessed','rejected','calibration_rejected','temporary') NULL,
  `output_status` ENUM('full', 'no_extra', 'deleted') NULL DEFAULT 'full',
  `launcher` ENUM('local', 'grid', 'dev_local', 'dev_grid') NULL DEFAULT 'local',
  `launcher_id` INT UNSIGNED NULL,
  `reference` VARCHAR(255) NULL,
  `step` TINYINT UNSIGNED NULL,
  `start_time` TIMESTAMP NULL,
  `end_time` TIMESTAMP NULL,
  `obs_date` TIMESTAMP NULL,
  `obs_night` DATE NULL,
  `obs_id` VARCHAR(255) NULL,
  `log` MEDIUMTEXT NULL,
  `grid_log` MEDIUMTEXT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_process_recipe1_idx` (`recipe_id` ASC),
  INDEX `fk_process_batch1_idx` (`batch_id` ASC),
  INDEX `fk_process_preset1_idx` (`preset_id` ASC),
  INDEX `fk_process_process1_idx` (`parent_process_id` ASC),
  INDEX `fk_process_process2_idx` (`top_parent_process_id` ASC),
  INDEX `fk_process_user1_idx` (`user_id` ASC),
  INDEX `fk_process_pipeline1_idx` (`data_pipeline_id` ASC),
  INDEX `fk_process_launcher1_idx` (`launcher_id` ASC),
  CONSTRAINT `fk_process_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_batch1`
    FOREIGN KEY (`batch_id`)
    REFERENCES `sphere`.`batch` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_preset1`
    FOREIGN KEY (`preset_id`)
    REFERENCES `sphere`.`preset` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_process1`
    FOREIGN KEY (`parent_process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_process2`
    FOREIGN KEY (`top_parent_process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_pipeline1`
    FOREIGN KEY (`data_pipeline_id`)
    REFERENCES `sphere`.`pipeline` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_launcher1`
    FOREIGN KEY (`launcher_id`)
    REFERENCES `sphere`.`launcher` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`reduced_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`reduced_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`reduced_data` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `frame_type_id` INT UNSIGNED NOT NULL,
  `process_id` INT UNSIGNED NOT NULL,
  `type` ENUM('observation','calibration') NOT NULL DEFAULT 'observation',
  `user_id` INT UNSIGNED NULL,
  `date` DATETIME NOT NULL,
  `obs_date` DATETIME NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_reduced_data_process1_idx` (`process_id` ASC),
  INDEX `fk_reduced_data_frame_type1` (`frame_type_id` ASC),
  INDEX `fk_reduced_data_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_reduced_data_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_reduced_data_data_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_reduced_data_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`star`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`star` ;

CREATE TABLE IF NOT EXISTS `sphere`.`star` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `identifier` VARCHAR(255) NOT NULL,
  `group_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_stat_identifier` (`identifier` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`analysis`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`analysis` ;

CREATE TABLE IF NOT EXISTS `sphere`.`analysis` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`candidate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`candidate` ;

CREATE TABLE IF NOT EXISTS `sphere`.`candidate` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `star_id` INT UNSIGNED NOT NULL,
  `analysis_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_candidate_analysis1_idx` (`analysis_id` ASC),
  INDEX `fk_candidate_star1_idx` (`star_id` ASC),
  CONSTRAINT `fk_candidate_analysis1`
    FOREIGN KEY (`analysis_id`)
    REFERENCES `sphere`.`analysis` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_candidate_star1`
    FOREIGN KEY (`star_id`)
    REFERENCES `sphere`.`star` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`parameter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`parameter` ;

CREATE TABLE IF NOT EXISTS `sphere`.`parameter` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) NOT NULL,
  `is_optional` ENUM('true','false') NOT NULL DEFAULT 'true',
  `type` ENUM('int', 'float', 'bool', 'string', 'flag', 'array', 'text', 'file', 'sof') NULL,
  `default_value` VARCHAR(255) NULL,
  `min_value` VARCHAR(255) NULL,
  `max_value` VARCHAR(255) NULL,
  `description` TEXT NULL,
  PRIMARY KEY (`id`, `name`),
  INDEX `fk_parameter_recipe_idx` (`recipe_id` ASC),
  UNIQUE INDEX `uq_recipe_id_name` (`recipe_id` ASC, `name` ASC),
  CONSTRAINT `fk_parameter_recipe`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`process_parameter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`process_parameter` ;

CREATE TABLE IF NOT EXISTS `sphere`.`process_parameter` (
  `process_id` INT UNSIGNED NOT NULL,
  `parameter_id` INT UNSIGNED NOT NULL,
  `value` VARCHAR(255) NULL,
  PRIMARY KEY (`process_id`, `parameter_id`),
  INDEX `fk_process_parameter_parameter1_idx` (`parameter_id` ASC),
  INDEX `fk_process_parameter_process1_idx` (`process_id` ASC),
  CONSTRAINT `fk_process_parameter_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_parameter_parameter1`
    FOREIGN KEY (`parameter_id`)
    REFERENCES `sphere`.`parameter` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`process_raw_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`process_raw_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`process_raw_data` (
  `process_id` INT UNSIGNED NOT NULL,
  `raw_data_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`process_id`, `raw_data_id`),
  INDEX `fk_process_raw_data_raw_data1_idx` (`raw_data_id` ASC),
  INDEX `fk_process_raw_data_process1_idx` (`process_id` ASC),
  CONSTRAINT `fk_process_raw_data_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_raw_data_raw_data1`
    FOREIGN KEY (`raw_data_id`)
    REFERENCES `sphere`.`raw_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`process_reduced_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`process_reduced_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`process_reduced_data` (
  `process_id` INT UNSIGNED NOT NULL,
  `reduced_data_id` INT UNSIGNED NOT NULL,
  `in_out` ENUM('in','out') NOT NULL DEFAULT 'in',
  PRIMARY KEY (`process_id`, `reduced_data_id`),
  INDEX `fk_process_reduced_data_reduced_data1_idx` (`reduced_data_id` ASC),
  INDEX `fk_process_reduced_data_process1_idx` (`process_id` ASC),
  CONSTRAINT `fk_process_reduced_data_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_reduced_data_reduced_data1`
    FOREIGN KEY (`reduced_data_id`)
    REFERENCES `sphere`.`reduced_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`analysis_parameter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`analysis_parameter` ;

CREATE TABLE IF NOT EXISTS `sphere`.`analysis_parameter` (
  `analysis_id` INT UNSIGNED NOT NULL,
  `parameter_id` INT UNSIGNED NOT NULL,
  `value` VARCHAR(45) NULL,
  PRIMARY KEY (`analysis_id`, `parameter_id`),
  INDEX `fk_analysis_parameter_parameter1_idx` (`parameter_id` ASC),
  INDEX `fk_analysis_parameter_analysis1_idx` (`analysis_id` ASC),
  CONSTRAINT `fk_analysis_parameter_analysis1`
    FOREIGN KEY (`analysis_id`)
    REFERENCES `sphere`.`analysis` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_analysis_parameter_parameter1`
    FOREIGN KEY (`parameter_id`)
    REFERENCES `sphere`.`parameter` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`analysis_reduced_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`analysis_reduced_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`analysis_reduced_data` (
  `analysis_id` INT UNSIGNED NOT NULL,
  `reduced_data_id` INT UNSIGNED NOT NULL,
  `in_out` ENUM('in','out') NOT NULL DEFAULT 'in',
  PRIMARY KEY (`analysis_id`, `reduced_data_id`),
  INDEX `fk_analysis_reduced_data_reduced_data1_idx` (`reduced_data_id` ASC),
  INDEX `fk_analysis_reduced_data_analysis1_idx` (`analysis_id` ASC),
  CONSTRAINT `fk_analysis_reduced_data_analysis1`
    FOREIGN KEY (`analysis_id`)
    REFERENCES `sphere`.`analysis` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_analysis_reduced_data_reduced_data1`
    FOREIGN KEY (`reduced_data_id`)
    REFERENCES `sphere`.`reduced_data` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`keyword`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`keyword` ;

CREATE TABLE IF NOT EXISTS `sphere`.`keyword` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `type` ENUM('string','bool','int','double','_auto_import') NOT NULL DEFAULT 'string',
  `description` TEXT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `name_UNIQUE` (`name` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`recipe_frame`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`recipe_frame` ;

CREATE TABLE IF NOT EXISTS `sphere`.`recipe_frame` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `frame_type_id` INT UNSIGNED NOT NULL,
  `in_out` ENUM('in','out') NOT NULL DEFAULT 'in',
  `is_optional` ENUM('true','false') NOT NULL DEFAULT 'true',
  `order` TINYINT NULL,
  `format` VARCHAR(32) NULL,
  `min_num` INT NULL,
  `max_num` INT NULL,
  `description` TEXT NULL COMMENT 'Default value in frame_type table',
  PRIMARY KEY (`id`),
  INDEX `fk_recipe_frame_type_frame_type1` (`frame_type_id` ASC),
  INDEX `fk_recipe_frame_type_recipe1` (`recipe_id` ASC),
  CONSTRAINT `fk_recipe_frame_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_frame_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`recipe_keyword`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`recipe_keyword` ;

CREATE TABLE IF NOT EXISTS `sphere`.`recipe_keyword` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `keyword_id` INT UNSIGNED NOT NULL,
  `in_out` ENUM('in','out') NOT NULL DEFAULT 'in',
  `is_optional` ENUM('true','false') NULL DEFAULT 'true',
  `frame_type_id` INT UNSIGNED NULL,
  `description` TEXT NULL COMMENT 'Default value in keyword table',
  PRIMARY KEY (`id`),
  INDEX `fk_recipe_keyword_keyword1_idx` (`keyword_id` ASC),
  INDEX `fk_recipe_keyword_recipe1_idx` (`recipe_id` ASC),
  INDEX `fk_recipe_keyword_frame_type1_idx` (`frame_type_id` ASC),
  CONSTRAINT `fk_recipe_keyword_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_keyword_keyword1`
    FOREIGN KEY (`keyword_id`)
    REFERENCES `sphere`.`keyword` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_recipe_keyword_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workflow_recipe`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workflow_recipe` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workflow_recipe` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `workflow_id` INT UNSIGNED NOT NULL,
  `recipe_id` INT UNSIGNED NOT NULL,
  `custom_frame_type_id` INT UNSIGNED NULL,
  `step` TINYINT UNSIGNED NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_workflow_recipe_recipe1_idx` (`recipe_id` ASC),
  INDEX `fk_workflow_recipe_workflow1_idx` (`workflow_id` ASC),
  UNIQUE INDEX `uq_workflow_recipe_step_ft` (`workflow_id` ASC, `recipe_id` ASC, `step` ASC, `custom_frame_type_id` ASC),
  INDEX `fk_workflow_recipe_frame_type1_idx` (`custom_frame_type_id` ASC),
  CONSTRAINT `fk_workflow_recipe_workflow1`
    FOREIGN KEY (`workflow_id`)
    REFERENCES `sphere`.`workflow` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workflow_recipe_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workflow_recipe_frame_type1`
    FOREIGN KEY (`custom_frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`preset_parameter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`preset_parameter` ;

CREATE TABLE IF NOT EXISTS `sphere`.`preset_parameter` (
  `preset_id` INT UNSIGNED NOT NULL,
  `parameter_id` INT UNSIGNED NOT NULL,
  `value` VARCHAR(255) NULL,
  PRIMARY KEY (`preset_id`, `parameter_id`),
  INDEX `fk_preset_parameter_parameter1_idx` (`parameter_id` ASC),
  INDEX `fk_preset_parameter_preset1_idx` (`preset_id` ASC),
  CONSTRAINT `fk_preset_parameter_preset1`
    FOREIGN KEY (`preset_id`)
    REFERENCES `sphere`.`preset` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_preset_parameter_parameter1`
    FOREIGN KEY (`parameter_id`)
    REFERENCES `sphere`.`parameter` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`reduced_data_file`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`reduced_data_file` ;

CREATE TABLE IF NOT EXISTS `sphere`.`reduced_data_file` (
  `reduced_data_id` INT UNSIGNED NOT NULL,
  `file_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`reduced_data_id`, `file_id`),
  INDEX `fk_reduced_data_file_file1_idx` (`file_id` ASC),
  INDEX `fk_reduced_data_file_reduced_data1_idx` (`reduced_data_id` ASC),
  CONSTRAINT `fk_reduced_data_file_reduced_data1`
    FOREIGN KEY (`reduced_data_id`)
    REFERENCES `sphere`.`reduced_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_reduced_data_file_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`raw_data_file`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`raw_data_file` ;

CREATE TABLE IF NOT EXISTS `sphere`.`raw_data_file` (
  `raw_data_id` INT UNSIGNED NOT NULL,
  `file_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`raw_data_id`, `file_id`),
  INDEX `fk_raw_data_file_file1_idx` (`file_id` ASC),
  INDEX `fk_raw_data_file_raw_data1_idx` (`raw_data_id` ASC),
  CONSTRAINT `fk_raw_data_file_raw_data1`
    FOREIGN KEY (`raw_data_id`)
    REFERENCES `sphere`.`raw_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_raw_data_file_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`file_extension`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`file_extension` ;

CREATE TABLE IF NOT EXISTS `sphere`.`file_extension` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `file_id` INT UNSIGNED NOT NULL,
  `number` TINYINT NOT NULL,
  `class` ENUM('image','basic','table','asciitable','binarytable','unknown') NOT NULL DEFAULT 'image',
  `category` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_extension_file1_idx` (`file_id` ASC),
  UNIQUE INDEX `uq_file_id_extension_number` (`file_id` ASC, `number` ASC),
  CONSTRAINT `fk_extension_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`file_extension_keyword`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`file_extension_keyword` ;

CREATE TABLE IF NOT EXISTS `sphere`.`file_extension_keyword` (
  `file_extension_id` INT UNSIGNED NOT NULL,
  `keyword_id` INT UNSIGNED NOT NULL,
  `value` VARCHAR(255) NULL,
  `core_value` VARCHAR(255) NULL,
  PRIMARY KEY (`file_extension_id`, `keyword_id`),
  INDEX `fk_file_extension_keyword_keyword1_idx` (`keyword_id` ASC),
  INDEX `fk_file_extension_keyword_file_extension1_idx` (`file_extension_id` ASC),
  INDEX `file_extension_keyword_core_value` (`core_value` ASC),
  UNIQUE INDEX `uq_file_extension_keyword1` (`file_extension_id` ASC, `keyword_id` ASC),
  CONSTRAINT `fk_file_extension_keyword_file_extension1`
    FOREIGN KEY (`file_extension_id`)
    REFERENCES `sphere`.`file_extension` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_file_extension_keyword_keyword1`
    FOREIGN KEY (`keyword_id`)
    REFERENCES `sphere`.`keyword` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workflow_recipe_parent`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workflow_recipe_parent` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workflow_recipe_parent` (
  `workflow_recipe_id` INT UNSIGNED NOT NULL,
  `parent_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`workflow_recipe_id`, `parent_id`),
  INDEX `fk_workflow_recipe_workflow_recipe_workflow_recipe2_idx` (`parent_id` ASC),
  INDEX `fk_workflow_recipe_workflow_recipe_workflow_recipe1_idx` (`workflow_recipe_id` ASC),
  CONSTRAINT `fk_workflow_recipe_workflow_recipe_workflow_recipe1`
    FOREIGN KEY (`workflow_recipe_id`)
    REFERENCES `sphere`.`workflow_recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workflow_recipe_workflow_recipe_workflow_recipe2`
    FOREIGN KEY (`parent_id`)
    REFERENCES `sphere`.`workflow_recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workflowpreset_preset`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workflowpreset_preset` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workflowpreset_preset` (
  `workflowpreset_id` INT UNSIGNED NOT NULL,
  `preset_id` INT UNSIGNED NOT NULL,
  `step` TINYINT UNSIGNED NOT NULL,
  PRIMARY KEY (`workflowpreset_id`, `preset_id`, `step`),
  INDEX `fk_workflowpreset_preset_preset1_idx` (`preset_id` ASC),
  INDEX `fk_workflowpreset_preset_workflowpreset1_idx` (`workflowpreset_id` ASC),
  CONSTRAINT `fk_workflowpreset_preset_workflowpreset1`
    FOREIGN KEY (`workflowpreset_id`)
    REFERENCES `sphere`.`workflowpreset` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workflowpreset_preset_preset1`
    FOREIGN KEY (`preset_id`)
    REFERENCES `sphere`.`preset` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`session`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`session` ;

CREATE TABLE IF NOT EXISTS `sphere`.`session` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NOT NULL,
  `session` VARCHAR(40) NOT NULL,
  `ip` VARCHAR(24) NULL,
  `creation_date` TIMESTAMP NOT NULL,
  `until_date` TIMESTAMP NOT NULL,
  `last_action` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_session_user1_idx` (`user_id` ASC),
  UNIQUE INDEX `key_UNIQUE` (`session` ASC),
  CONSTRAINT `fk_session_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`request_user`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`request_user` ;

CREATE TABLE IF NOT EXISTS `sphere`.`request_user` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `email` VARCHAR(255) NOT NULL,
  `ident` VARCHAR(255) NULL,
  `password` VARCHAR(32) NOT NULL,
  `request_date` TIMESTAMP NOT NULL,
  `request_ip` VARCHAR(24) NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `email_UNIQUE` (`email` ASC),
  UNIQUE INDEX `ident_UNIQUE` (`ident` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workspace_process`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workspace_process` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workspace_process` (
  `workspace_id` INT UNSIGNED NOT NULL,
  `process_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`workspace_id`, `process_id`),
  INDEX `fk_workspace_process_process1_idx` (`process_id` ASC),
  INDEX `fk_workspace_process_workspace1_idx` (`workspace_id` ASC),
  CONSTRAINT `fk_workspace_process_workspace1`
    FOREIGN KEY (`workspace_id`)
    REFERENCES `sphere`.`workspace` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workspace_process_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workspace_file`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workspace_file` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workspace_file` (
  `workspace_id` INT UNSIGNED NOT NULL,
  `file_id` INT UNSIGNED NOT NULL,
  `source` ENUM('process', 'public_calib', 'clone', 'import_duplicate') NULL,
  PRIMARY KEY (`workspace_id`, `file_id`),
  INDEX `fk_workspace_file_file1_idx` (`file_id` ASC),
  INDEX `fk_workspace_file_workspace1_idx` (`workspace_id` ASC),
  CONSTRAINT `fk_workspace_file_workspace1`
    FOREIGN KEY (`workspace_id`)
    REFERENCES `sphere`.`workspace` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workspace_file_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`workspace_shared_user`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`workspace_shared_user` ;

CREATE TABLE IF NOT EXISTS `sphere`.`workspace_shared_user` (
  `workspace_id` INT UNSIGNED NOT NULL,
  `shared_user_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`workspace_id`, `shared_user_id`),
  INDEX `fk_workspace_user_user1_idx` (`shared_user_id` ASC),
  INDEX `fk_workspace_user_workspace1_idx` (`workspace_id` ASC),
  CONSTRAINT `fk_workspace_shared_user_workspace1`
    FOREIGN KEY (`workspace_id`)
    REFERENCES `sphere`.`workspace` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_workspace_shared_user_user1`
    FOREIGN KEY (`shared_user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`user_key`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`user_key` ;

CREATE TABLE IF NOT EXISTS `sphere`.`user_key` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NOT NULL,
  `alias` VARCHAR(255) NOT NULL,
  `key` VARCHAR(255) NOT NULL,
  `type` ENUM('private','public') NOT NULL DEFAULT 'public',
  `date` TIMESTAMP NULL,
  `expiration_date` TIMESTAMP NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_user_key_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_user_key_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`file_star`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`file_star` ;

CREATE TABLE IF NOT EXISTS `sphere`.`file_star` (
  `file_id` INT UNSIGNED NOT NULL,
  `star_id` INT UNSIGNED NOT NULL,
  `distance` DOUBLE NULL,
  `type` VARCHAR(255) NULL,
  `is_nearest` ENUM('true','false') NOT NULL DEFAULT 'false',
  PRIMARY KEY (`file_id`, `star_id`),
  INDEX `fk_file_star_star1_idx` (`star_id` ASC),
  INDEX `fk_file_star_file1_idx` (`file_id` ASC),
  CONSTRAINT `fk_file_star_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_file_star_star1`
    FOREIGN KEY (`star_id`)
    REFERENCES `sphere`.`star` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`attribute_cache`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`attribute_cache` ;

CREATE TABLE IF NOT EXISTS `sphere`.`attribute_cache` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `file_id` INT UNSIGNED NULL,
  `raw_data_id` INT UNSIGNED NULL,
  `reduced_data_id` INT UNSIGNED NULL,
  `parent_process_id` INT UNSIGNED NULL,
  `parent_batch_id` INT UNSIGNED NULL,
  `data_type` ENUM('observation','calibration') NULL,
  `frame_type_id` INT UNSIGNED NULL,
  `frame_type` VARCHAR(255) NULL,
  `obs_date` DATETIME NULL,
  `night_date` DATE NULL,
  `directory_date` DATE NULL,
  `instrument` VARCHAR(255) NULL,
  `is_standard` ENUM('true','false') NULL,
  `naxis1` INT NULL,
  `naxis2` INT NULL,
  `naxis3` INT NULL,
  `coord_RA` DOUBLE NULL,
  `coord_DEC` DOUBLE NULL,
  `coord_x` DOUBLE NULL,
  `coord_y` DOUBLE NULL,
  `coord_z` DOUBLE NULL,
  `exp_time` DOUBLE NULL,
  `dpr_type` VARCHAR(255) NULL,
  `dpr_tech` VARCHAR(255) NULL,
  `dpr_categ` VARCHAR(255) NULL,
  `pro_type` VARCHAR(255) NULL,
  `pro_tech` VARCHAR(255) NULL,
  `pro_categ` VARCHAR(255) NULL,
  `inst_filter` VARCHAR(255) NULL,
  `pi_coi` VARCHAR(255) NULL,
  `prog_id` VARCHAR(255) NULL,
  `obs_id` VARCHAR(255) NULL,
  `object` VARCHAR(255) NULL,
  `target` VARCHAR(255) NULL,
  `neutral_density` VARCHAR(255) NULL,
  `readout_mode` VARCHAR(255) NULL,
  `coro` VARCHAR(255) NULL,
  `derotator_mode` VARCHAR(255) NULL,
  `mjd_obs` DOUBLE NULL,
  `container_id` VARCHAR(255) NULL,
  `ndit` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_attribute_cache_file1_idx` (`file_id` ASC),
  INDEX `fk_attribute_cache_raw_data1_idx` (`raw_data_id` ASC),
  INDEX `fk_attribute_cache_reduced_data1_idx` (`reduced_data_id` ASC),
  INDEX `fk_attribute_cache_process1_idx` (`parent_process_id` ASC),
  INDEX `fk_attribute_cache_batch1_idx` (`parent_batch_id` ASC),
  CONSTRAINT `fk_attribute_cache_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_attribute_cache_raw_data1`
    FOREIGN KEY (`raw_data_id`)
    REFERENCES `sphere`.`raw_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_attribute_cache_reduced_data1`
    FOREIGN KEY (`reduced_data_id`)
    REFERENCES `sphere`.`reduced_data` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_attribute_cache_process1`
    FOREIGN KEY (`parent_process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_attribute_cache_batch1`
    FOREIGN KEY (`parent_batch_id`)
    REFERENCES `sphere`.`batch` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`process_custom_frame_type`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`process_custom_frame_type` ;

CREATE TABLE IF NOT EXISTS `sphere`.`process_custom_frame_type` (
  `process_id` INT UNSIGNED NOT NULL,
  `file_id` INT UNSIGNED NOT NULL,
  `frame_type_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`process_id`, `file_id`, `frame_type_id`),
  INDEX `fk_process_file_file1_idx` (`file_id` ASC),
  INDEX `fk_process_file_process1_idx` (`process_id` ASC),
  INDEX `fk_process_custom_frame_type_frame_type1_idx` (`frame_type_id` ASC),
  CONSTRAINT `fk_process_custom_frame_type_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_custom_frame_type_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_process_custom_frame_type_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`stat_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`stat_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`stat_data` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `type` ENUM('total','daily') NULL,
  `project` ENUM('sphere', 'cobrex') NULL,
  `date` DATE NULL,
  `file_count` INT NULL,
  `raw_data_count` INT NULL,
  `reduced_data_count` INT NULL,
  `unused_raw_data_count` INT NULL,
  `calibration_count` INT NULL,
  `observation_count` INT NULL,
  `extra_output_count` INT NULL,
  `temporary_count` INT NULL,
  `free_space` BIGINT NULL,
  `total_file_size` BIGINT NULL,
  `total_file_fs_size` BIGINT NULL,
  `raw_data_size` BIGINT NULL,
  `raw_data_fs_size` BIGINT NULL,
  `unused_raw_data_size` BIGINT NULL,
  `unused_raw_data_fs_size` BIGINT NULL,
  `stat_datacol` VARCHAR(45) NULL,
  `reduced_data_size` BIGINT NULL,
  `reduced_data_fs_size` BIGINT NULL,
  `reduced_data_ext_size` BIGINT NULL,
  `reduced_data_del_size` BIGINT NULL,
  `extra_output_size` BIGINT NULL,
  `extra_output_fs_size` BIGINT NULL,
  `extra_output_ext_size` BIGINT NULL,
  `extra_output_del_size` BIGINT NULL,
  `temporary_size` BIGINT NULL,
  `temporary_fs_size` BIGINT NULL,
  `temporary_ext_size` BIGINT NULL,
  `file_status` VARCHAR(255) NULL,
  `file_types` VARCHAR(255) NULL,
  `file_compressions` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `stat_data_uq_date_type_project` (`date` ASC, `type` ASC, `project` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`stat_process`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`stat_process` ;

CREATE TABLE IF NOT EXISTS `sphere`.`stat_process` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `type` ENUM('total','daily') NULL,
  `project` ENUM('sphere', 'cobrex') NULL,
  `date` DATE NULL,
  `output_count` INT NULL,
  `extra_output_count` INT NULL,
  `total_output_count` INT NULL,
  `process_count` INT NULL,
  `used_process_count` INT NULL,
  `temporary_process_count` INT NULL,
  `output_size` BIGINT NULL,
  `output_fs_size` BIGINT NULL,
  `output_ext_size` BIGINT NULL,
  `output_del_size` BIGINT NULL,
  `extra_output_size` BIGINT NULL,
  `extra_output_fs_size` BIGINT NULL,
  `extra_output_ext_size` BIGINT NULL,
  `extra_output_del_size` BIGINT NULL,
  `total_output_size` BIGINT NULL,
  `total_output_fs_size` BIGINT NULL,
  `total_output_ext_size` BIGINT NULL,
  `total_output_del_size` BIGINT NULL,
  `temporary_size` BIGINT NULL,
  `temporary_fs_size` BIGINT NULL,
  `temporary_ext_size` BIGINT NULL,
  `process_status` VARCHAR(255) NULL,
  `process_validation_status` VARCHAR(255) NULL,
  `process_output_status` VARCHAR(255) NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `stat_process_uq_date_type_project` (`type` ASC, `date` ASC, `project` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`maintenance_control`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`maintenance_control` ;

CREATE TABLE IF NOT EXISTS `sphere`.`maintenance_control` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NULL,
  `batch_id` INT UNSIGNED NULL,
  `status` ENUM('started','stopped','finished') NOT NULL DEFAULT 'started',
  `timer_filename` VARCHAR(255) NULL,
  `start_time` DATETIME NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_maintenance_control_user1_idx` (`user_id` ASC),
  INDEX `fk_maintenance_control_batch1_idx` (`batch_id` ASC),
  CONSTRAINT `fk_maintenance_control_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_maintenance_control_batch1`
    FOREIGN KEY (`batch_id`)
    REFERENCES `sphere`.`batch` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`message`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`message` ;

CREATE TABLE IF NOT EXISTS `sphere`.`message` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NOT NULL,
  `workspace_id` INT UNSIGNED NULL,
  `process_id` INT UNSIGNED NULL,
  `file_id` INT UNSIGNED NULL,
  `type` ENUM('message', 'note') NOT NULL DEFAULT 'message',
  `title` VARCHAR(255) NOT NULL,
  `message` TEXT NOT NULL,
  `date` TIMESTAMP NOT NULL,
  `ip` VARCHAR(24) NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_message_user1_idx` (`user_id` ASC),
  INDEX `fk_message_workspace1_idx` (`workspace_id` ASC),
  INDEX `fk_message_process1_idx` (`process_id` ASC),
  INDEX `fk_message_file1_idx` (`file_id` ASC),
  CONSTRAINT `fk_message_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_message_workspace1`
    FOREIGN KEY (`workspace_id`)
    REFERENCES `sphere`.`workspace` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_message_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_message_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`storage`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`storage` ;

CREATE TABLE IF NOT EXISTS `sphere`.`storage` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `server` VARCHAR(255) NOT NULL,
  `type` ENUM('local', 'sphere', 'cobrex', 'grid_local', 'grid_scratch') NOT NULL,
  `path` VARCHAR(255) NOT NULL,
  `substorage` SMALLINT(6) NULL,
  `shared_path` VARCHAR(255) NOT NULL,
  `is_used` ENUM('true', 'false') NOT NULL DEFAULT 'true',
  `is_capacitive` ENUM('true', 'false') NOT NULL DEFAULT 'false',
  `free_space` BIGINT NULL,
  `min_space` VARCHAR(255) NULL,
  `maintenance_on` DATETIME NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_storage_name_1` (`name` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`session_log`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`session_log` ;

CREATE TABLE IF NOT EXISTS `sphere`.`session_log` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `user_id` INT UNSIGNED NOT NULL,
  `from` VARCHAR(255) NULL,
  `ip` VARCHAR(24) NULL,
  `date` TIMESTAMP NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_session_log_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_session_log_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`attribute_cache_extended`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`attribute_cache_extended` ;

CREATE TABLE IF NOT EXISTS `sphere`.`attribute_cache_extended` (
  `attribute_cache_id` INT UNSIGNED NOT NULL,
  `eso_dpr_type` VARCHAR(255) NULL,
  `eso_dpr_tech` VARCHAR(255) NULL,
  `eso_dpr_catg` VARCHAR(255) NULL,
  `eso_obs_prog_id` VARCHAR(255) NULL,
  `eso_obs_start` DATETIME NULL,
  `eso_obs_targ_name` VARCHAR(255) NULL,
  `eso_tel_ia_fwhm` DOUBLE NULL,
  `eso_tel_ia_fwhmlin` DOUBLE NULL,
  `eso_tel_ia_fwhmlinobs` DOUBLE NULL,
  `eso_det_seq1_dit` DOUBLE NULL,
  `eso_det_ndit` INT NULL,
  `eso_det_read_curname` VARCHAR(255) NULL,
  `eso_det_dit1` VARCHAR(255) NULL,
  `eso_ins1_filt2_name` VARCHAR(255) NULL,
  `eso_ins1_opti2_name` VARCHAR(255) NULL,
  `eso_ins3_opti2_name` VARCHAR(255) NULL,
  `eso_ins3_opti5_name` VARCHAR(255) NULL,
  `eso_ins3_opti6_name` VARCHAR(255) NULL,
  `eso_ins3_opti17_name` VARCHAR(255) NULL,
  `eso_ins3_mode` VARCHAR(255) NULL,
  `eso_ins4_opti16_name` VARCHAR(255) NULL,
  `eso_ins4_opti17_name` VARCHAR(255) NULL,
  `eso_ins4_opti10_name` VARCHAR(255) NULL,
  `eso_ins4_opti11_name` VARCHAR(255) NULL,
  `eso_ins4_comb_ind` VARCHAR(255) NULL,
  `eso_ins4_filt2_name` VARCHAR(255) NULL,
  `eso_ins4_drot1_posang` DOUBLE NULL,
  `eso_ins4_drot2_posang` DOUBLE NULL,
  `eso_ins4_drot3_posang` DOUBLE NULL,
  `eso_ins4_temp422_val` DOUBLE NULL,
  `eso_ins4_sens428_val` DOUBLE NULL,
  `eso_seq_arm` VARCHAR(255) NULL,
  `eso_ocs_dpi_h2rt_stokes` VARCHAR(255) NULL,
  `eso_aos_viswfs_mode` VARCHAR(255) NULL,
  `eso_aos_irwfs_mode` VARCHAR(255) NULL,
  `eso_aos_holoop_state` VARCHAR(255) NULL,
  `eso_aos_irloop_state` VARCHAR(255) NULL,
  `eso_aos_puploop_state` VARCHAR(255) NULL,
  `eso_aos_ttloop_state` VARCHAR(255) NULL,
  `eso_tpl_id` VARCHAR(255) NULL,
  `eso_tpl_nexp` INT NULL,
  `eso_tpl_expno` INT NULL,
  `eso_tpl_start` DATETIME NULL,
  `eso_tel_parang_start` DOUBLE NULL,
  `eso_tel_parang_end` DOUBLE NULL,
  `eso_tel_alt` DOUBLE NULL,
  `eso_tel_az` DOUBLE NULL,
  `eso_tel_airm_start` DOUBLE NULL,
  `eso_tel_airm_end` DOUBLE NULL,
  `eso_tel_ambi_fwhm_end` DOUBLE NULL,
  `eso_tel_ambi_fwhm_start` DOUBLE NULL,
  `eso_tel_ambi_pres_end` DOUBLE NULL,
  `eso_tel_ambi_pres_start` DOUBLE NULL,
  `eso_tel_ambi_rhum` DOUBLE NULL,
  `eso_tel_ambi_tau0` DOUBLE NULL,
  `eso_tel_ambi_temp` DOUBLE NULL,
  `eso_tel_ambi_winddir` DOUBLE NULL,
  `eso_tel_ambi_windsp` DOUBLE NULL,
  `eso_ins_comb_icor` VARCHAR(255) NULL,
  `eso_ins_comb_iflt` VARCHAR(255) NULL,
  `eso_ins_comb_pola` VARCHAR(255) NULL,
  `eso_ins_comb_vcor` VARCHAR(255) NULL,
  PRIMARY KEY (`attribute_cache_id`),
  INDEX `fk_attribute_cache_extended_attribute_cache1_idx` (`attribute_cache_id` ASC),
  CONSTRAINT `fk_attribute_cache_extended_attribute_cache1`
    FOREIGN KEY (`attribute_cache_id`)
    REFERENCES `sphere`.`attribute_cache` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`maintenance_helper`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`maintenance_helper` ;

CREATE TABLE IF NOT EXISTS `sphere`.`maintenance_helper` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `type` VARCHAR(255) NOT NULL,
  `action` ENUM('append', 'skip', 'remove') NOT NULL DEFAULT 'append',
  PRIMARY KEY (`id`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`maintenance_helper_data`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`maintenance_helper_data` ;

CREATE TABLE IF NOT EXISTS `sphere`.`maintenance_helper_data` (
  `maintenance_helper_id` INT UNSIGNED NOT NULL,
  `item_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`maintenance_helper_id`, `item_id`),
  CONSTRAINT `fk_maintenance_helper_data_maintenance_helper1`
    FOREIGN KEY (`maintenance_helper_id`)
    REFERENCES `sphere`.`maintenance_helper` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`file_storage`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`file_storage` ;

CREATE TABLE IF NOT EXISTS `sphere`.`file_storage` (
  `file_id` INT UNSIGNED NOT NULL,
  `storage_id` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`file_id`, `storage_id`),
  INDEX `fk_file_storage_storage1_idx` (`storage_id` ASC),
  INDEX `fk_file_storage_file1_idx` (`file_id` ASC),
  CONSTRAINT `fk_file_storage_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_file_storage_storage1`
    FOREIGN KEY (`storage_id`)
    REFERENCES `sphere`.`storage` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`attribute_cache_reduction`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`attribute_cache_reduction` ;

CREATE TABLE IF NOT EXISTS `sphere`.`attribute_cache_reduction` (
  `attribute_cache_id` INT UNSIGNED NOT NULL,
  `reduction_id` INT UNSIGNED NULL,
  `reduction_state` ENUM('untreated', 'non_standard', 'standard', 'latest', 'tdb') NOT NULL DEFAULT 'untreated',
  INDEX `fk_attribute_cache_reduction_attribute_cache1_idx` (`attribute_cache_id` ASC),
  INDEX `attribute_cache_reduction_reduction_id1_idx` (`reduction_id` ASC),
  CONSTRAINT `fk_attribute_cache_reduction_attribute_cache1`
    FOREIGN KEY (`attribute_cache_id`)
    REFERENCES `sphere`.`attribute_cache` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`perf_server`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`perf_server` ;

CREATE TABLE IF NOT EXISTS `sphere`.`perf_server` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `type` ENUM('local', 'grid', 'grid_besteffort') NOT NULL DEFAULT 'local',
  `cores` INT UNSIGNED NULL,
  `memory` INT UNSIGNED NULL,
  `memcore` INT UNSIGNED NULL,
  `is_used` ENUM('true', 'false') NOT NULL DEFAULT 'true',
  `status` ENUM('alive', 'suspected', 'dead') NOT NULL DEFAULT 'alive',
  PRIMARY KEY (`id`),
  UNIQUE INDEX `uq_perf_server_name` (`name` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`perf_recipe`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`perf_recipe` ;

CREATE TABLE IF NOT EXISTS `sphere`.`perf_recipe` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `recipe_id` INT UNSIGNED NOT NULL,
  `perf_server_id` INT UNSIGNED NOT NULL,
  `options` VARCHAR(255) NOT NULL DEFAULT 'default' COMMENT 'Preset or options hash',
  `server_options` VARCHAR(255) NOT NULL DEFAULT 'default',
  `usage_count` INT UNSIGNED NOT NULL DEFAULT 0,
  `performance` DOUBLE UNSIGNED NULL,
  `min_memory` BIGINT UNSIGNED NULL,
  `memory_ratio` DOUBLE UNSIGNED NULL,
  `cpu` DOUBLE UNSIGNED NULL,
  `cores_nb` INT UNSIGNED NULL,
  PRIMARY KEY (`id`, `recipe_id`, `perf_server_id`, `options`, `server_options`),
  INDEX `fk_perf_recipe_recipe1_idx` (`recipe_id` ASC),
  INDEX `fk_perf_recipe_perf_server1_idx` (`perf_server_id` ASC),
  CONSTRAINT `fk_perf_recipe_recipe1`
    FOREIGN KEY (`recipe_id`)
    REFERENCES `sphere`.`recipe` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_perf_recipe_perf_server1`
    FOREIGN KEY (`perf_server_id`)
    REFERENCES `sphere`.`perf_server` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`perf_process`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`perf_process` ;

CREATE TABLE IF NOT EXISTS `sphere`.`perf_process` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `process_id` INT UNSIGNED NOT NULL,
  `perf_server_id` INT UNSIGNED NOT NULL,
  `options` VARCHAR(255) NOT NULL DEFAULT 'default' COMMENT 'Preset or options hash',
  `server_options` VARCHAR(255) NOT NULL DEFAULT 'default',
  `estimated_duration` INT UNSIGNED NULL,
  `duration` INT UNSIGNED NULL,
  `performance` DOUBLE UNSIGNED NULL,
  `performance_deviation` DOUBLE UNSIGNED NULL,
  `input_size` BIGINT UNSIGNED NULL,
  `output_size` BIGINT UNSIGNED NULL,
  `extra_output_size` BIGINT UNSIGNED NULL,
  `main_input_size` BIGINT UNSIGNED NULL,
  `fetch_size` BIGINT UNSIGNED NULL,
  `memory` BIGINT UNSIGNED NULL,
  `memory_ratio` DOUBLE UNSIGNED NULL,
  `cpu` DOUBLE UNSIGNED NULL,
  `cores_nb` INT UNSIGNED NULL,
  PRIMARY KEY (`id`, `process_id`, `perf_server_id`, `options`, `server_options`),
  INDEX `fk_perf_process_process1_idx` (`process_id` ASC),
  INDEX `fk_perf_process_perf_server1_idx` (`perf_server_id` ASC),
  CONSTRAINT `fk_perf_process_process1`
    FOREIGN KEY (`process_id`)
    REFERENCES `sphere`.`process` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_perf_process_perf_server1`
    FOREIGN KEY (`perf_server_id`)
    REFERENCES `sphere`.`perf_server` (`id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`stat_dl_log`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`stat_dl_log` ;

CREATE TABLE IF NOT EXISTS `sphere`.`stat_dl_log` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `file_id` INT UNSIGNED NULL,
  `frame_type_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `date` TIMESTAMP NOT NULL,
  `server` ENUM('sphere-dc', 'cobrex-dc', 'sphere-dc-dev', 'cobrex-dc-dev') NOT NULL,
  `url` VARCHAR(255) NOT NULL,
  `ip` VARCHAR(40) NULL,
  `params` VARCHAR(255) NULL,
  `size` BIGINT NULL,
  `source` ENUM('client', 'direct', 'api', 'script', 'tdb', 'js9', 'vo') NULL,
  `code` INT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_stat_dl_realtime_file1_idx` (`file_id` ASC),
  INDEX `fk_stat_dl_realtime_user1_idx` (`user_id` ASC),
  INDEX `fk_stat_dl_log_frame_type1_idx` (`frame_type_id` ASC),
  CONSTRAINT `fk_stat_dl_log_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `sphere`.`file` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_log_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_log_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`geoip_country`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`geoip_country` ;

CREATE TABLE IF NOT EXISTS `sphere`.`geoip_country` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `iso` VARCHAR(6) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `geoip_country_name1_uq` (`name` ASC),
  UNIQUE INDEX `geoip_country_iso1_uq` (`iso` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`geoip_city`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`geoip_city` ;

CREATE TABLE IF NOT EXISTS `sphere`.`geoip_city` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `latitude` DOUBLE NULL,
  `longitude` DOUBLE NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `geoip_city_name1_uq` (`name` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `sphere`.`stat_dl`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `sphere`.`stat_dl` ;

CREATE TABLE IF NOT EXISTS `sphere`.`stat_dl` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `frame_type_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `date` DATE NOT NULL,
  `server` ENUM('sphere-dc', 'cobrex-dc', 'sphere-dc-dev', 'cobrex-dc-dev') NOT NULL,
  `count` INT NOT NULL DEFAULT 0,
  `size` BIGINT NOT NULL DEFAULT 0,
  `source` ENUM('client', 'direct', 'api', 'script', 'tdb', 'js9', 'vo') NULL,
  `geoip_country_id` INT UNSIGNED NULL,
  `geoip_city_id` INT UNSIGNED NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_stat_dl_realtime_user1_idx` (`user_id` ASC),
  INDEX `fk_stat_dl_log_frame_type1_idx` (`frame_type_id` ASC),
  INDEX `fk_stat_dl_geoip_country1_idx` (`geoip_country_id` ASC),
  INDEX `fk_stat_dl_geoip_city1_idx` (`geoip_city_id` ASC),
  CONSTRAINT `fk_stat_dl_user10`
    FOREIGN KEY (`user_id`)
    REFERENCES `sphere`.`user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_frame_type10`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `sphere`.`frame_type` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_geoip_country1`
    FOREIGN KEY (`geoip_country_id`)
    REFERENCES `sphere`.`geoip_country` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_geoip_city1`
    FOREIGN KEY (`geoip_city_id`)
    REFERENCES `sphere`.`geoip_city` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
